package entities

import "github.com/go-gl/mathgl/mgl64"

// Entity definierar alla bas-objekt i varlden
type Entity interface {
Pos() mgl64.Vec3
SetPos(pos mgl64.Vec3)
IsBlocking() bool
IsMovable() bool
Move(dx, dy, dz float64)
Damage(amount int)
Pickup() bool
GetHealth() int

// Ritar ut framkallningen av spriten
// sideView: ifall vi ritar från sidan (vänster) eller uppifrån (höger)
DrawSide(screen interface{}, x, y float64)
DrawTop(screen interface{}, x, y float64)
}
